Arthur de Jong

Open Source / Free Software developer

summaryrefslogtreecommitdiffstats
path: root/nss/passwd.c
diff options
context:
space:
mode:
Diffstat (limited to 'nss/passwd.c')
-rw-r--r--nss/passwd.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/nss/passwd.c b/nss/passwd.c
index ee5e75a..b42fc00 100644
--- a/nss/passwd.c
+++ b/nss/passwd.c
@@ -29,9 +29,9 @@
#include "prototypes.h"
#include "common.h"
/* Macros for expanding the LDF_PASSWD macro. */
#define LDF_STRING(field) READ_STRING_BUF(fp,field)
#define LDF_TYPE(field,type) READ_TYPE(fp,field,type)
#define PASSWD_NAME result->pw_name
#define PASSWD_PASSWD result->pw_passwd
#define PASSWD_UID result->pw_uid
@@ -47,7 +47,7 @@ static enum nss_status read_passwd(
{
int32_t tmpint32;
size_t bufptr=0;
- LDF_PASSWD;
+ NSLCD_PASSWD;
return NSS_STATUS_SUCCESS;
}
@@ -29,9 +29,9 @@
#include "prototypes.h"
#include "common.h"
-/* Macros for expanding the LDF_PASSWD macro. */
-#define LDF_STRING(field) READ_STRING_BUF(fp,field)
-#define LDF_TYPE(field,type) READ_TYPE(fp,field,type)
+/* Macros for expanding the NSLCD_PASSWD macro. */
+#define NSLCD_STRING(field) READ_STRING_BUF(fp,field)
+#define NSLCD_TYPE(field,type) READ_TYPE(fp,field,type)
#define PASSWD_NAME result->pw_name
#define PASSWD_PASSWD result->pw_passwd